# -*- coding: utf-8 -*-
from typing import Any, ContextManager, Optional, Union

class ColourSelect(GenBitmapButton):
    """ A subclass of wx.lib.buttons.GenBitmapButton that,
when clicked, will display a colour selection dialog.

        Source: https://docs.wxpython.org/wx.lib.colourselect.ColourSelect.html
    """
    def __init__(self, parent, id=wx.ID_ANY, label="", colour=wx.BLACK, pos=wx.DefaultPosition, size=wx.DefaultSize, callback=None, style=0) -> None:
        """ Default class constructor.

            Source: https://docs.wxpython.org/wx.lib.colourselect.ColourSelect.html
        """

    def GetColour(self) -> 'Colour':
        """ Returns the current colour set for the ColourSelect.

            Source: https://docs.wxpython.org/wx.lib.colourselect.ColourSelect.html
        """

    def GetCustomColours(self) -> CustomColourData:
        """ Returns the current set of custom colour values to be shown in the
colour dialog, if supported.

            Source: https://docs.wxpython.org/wx.lib.colourselect.ColourSelect.html
        """

    def GetLabel(self) -> str:
        """ Returns the current text label for the ColourSelect.

            Source: https://docs.wxpython.org/wx.lib.colourselect.ColourSelect.html
        """

    def GetValue(self) -> 'Colour':
        """ Returns the current colour set for the ColourSelect.
Same as GetColour.

            Source: https://docs.wxpython.org/wx.lib.colourselect.ColourSelect.html
        """

    def MakeBitmap(self) -> None:
        """ Creates a bitmap representation of the current selected colour.

            Source: https://docs.wxpython.org/wx.lib.colourselect.ColourSelect.html
        """

    def OnChange(self) -> None:
        """ Fires the EVT_COLOURSELECT event, as the user has changed the current colour.

            Source: https://docs.wxpython.org/wx.lib.colourselect.ColourSelect.html
        """

    def OnClick(self, event: 'CommandEvent') -> None:
        """ Handles the wx.EVT_BUTTON event for ColourSelect.

            Source: https://docs.wxpython.org/wx.lib.colourselect.ColourSelect.html
        """

    def SetBitmap(self, bmp: 'Bitmap') -> None:
        """ Sets the bitmap representation of the current selected colour to the button.

            Source: https://docs.wxpython.org/wx.lib.colourselect.ColourSelect.html
        """

    def SetColour(self, colour: Union[int, str, 'Colour']) -> None:
        """ Sets the current colour for ColourSelect.

            Source: https://docs.wxpython.org/wx.lib.colourselect.ColourSelect.html
        """

    def SetCustomColours(self, colours: CustomColourData) -> None:
        """ Sets the list of custom colour values to be shown in colour dialog, if
supported.

            Source: https://docs.wxpython.org/wx.lib.colourselect.ColourSelect.html
        """

    def SetLabel(self, label: str) -> None:
        """ Sets the new text label for wx.ColourSelect.

            Source: https://docs.wxpython.org/wx.lib.colourselect.ColourSelect.html
        """

    def SetValue(self, colour: Union[int, str, 'Colour']) -> None:
        """ Sets the current colour for ColourSelect.  Same as
SetColour.

            Source: https://docs.wxpython.org/wx.lib.colourselect.ColourSelect.html
        """

    Colour: Any  # Returns the current colour set for the ColourSelect.
    CustomColours: Any  # Returns the current set of custom colour values to be shown in the
colour dialog, if supported.
    Label: Any  # Returns the current text label for the ColourSelect.
    Value: Any  # Returns the current colour set for the ColourSelect.
Same as GetColour.



EVT_BUTTON: int

class CustomColourData:
    """ A simple container for tracking custom colours to be shown in the colour
dialog, and which facilitates reuse of this collection across multiple
instances or multiple invocations of the ColourSelect button.

        Source: https://docs.wxpython.org/wx.lib.colourselect.CustomColourData.html
    """
    def __init__(self) -> None:
        """ Initialize self.  See help(type(self)) for accurate signature.

            Source: https://docs.wxpython.org/wx.lib.colourselect.CustomColourData.html
        """

    Colours: Any  # See Colours , Colours






# -*- coding: utf-8 -*-
from typing import Any, ContextManager, Optional, Union

class GLCanvas(Window):
    """ GLCanvas is a class for displaying OpenGL graphics.

        Source: https://docs.wxpython.org/wx.glcanvas.GLCanvas.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.glcanvas.GLCanvas.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.glcanvas.GLCanvas.html
        """

    @staticmethod
    def IsDisplaySupported(*args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.glcanvas.GLCanvas.html
        """

    @staticmethod
    def IsExtensionSupported(extension: int) -> bool:
        """ Returns True if the extension with given name is supported.

            Source: https://docs.wxpython.org/wx.glcanvas.GLCanvas.html
        """

    def SetColour(self, colour: str) -> bool:
        """ Sets the current colour for this window (using  glcolor3f() ), using the wxWidgets colour database to find a named colour.

            Source: https://docs.wxpython.org/wx.glcanvas.GLCanvas.html
        """

    def SetCurrent(self, context: 'glcanvas.GLContext') -> bool:
        """ Makes the OpenGL state that is represented by the OpenGL rendering context context  current, i.e.

            Source: https://docs.wxpython.org/wx.glcanvas.GLCanvas.html
        """

    def SwapBuffers(self) -> bool:
        """ Swaps the double-buffer of this window, making the back-buffer the front-buffer and vice versa, so that the output of the previous OpenGL commands is displayed on the window.

            Source: https://docs.wxpython.org/wx.glcanvas.GLCanvas.html
        """



WX_GL_RGBA: int

class GLContext(Object):
    """ An instance of a GLContext represents the state of an OpenGL state
machine and the connection between OpenGL and the system.

        Source: https://docs.wxpython.org/wx.glcanvas.GLContext.html
    """
    def __init__(self, win, other=None, ctxAttrs=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContext.html
        """

    def IsOK(self) -> bool:
        """ Checks if the underlying OpenGL rendering context was correctly created by the system with the requested attributes.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContext.html
        """

    def SetCurrent(self, win: 'glcanvas.GLCanvas') -> bool:
        """ Makes the OpenGL state that is represented by this rendering context current with the   wx.glcanvas.GLCanvas win.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContext.html
        """



class GLAttributes(GLAttribsBase):
    """ This class is used for setting display attributes when drawing through
OpenGL (âPixel formatâ in MSW and OSX parlance, âConfigsâ in X11).

        Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
    """
    def AuxBuffers(self, val: int) -> 'glcanvas.GLAttributes':
        """ Specifies the number of auxiliary buffers.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """

    def BufferSize(self, val: int) -> 'glcanvas.GLAttributes':
        """ Specifies the number of bits for colour buffer.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """

    def Defaults(self) -> 'glcanvas.GLAttributes':
        """ wxWidgets defaults: RGBA, Z-depth 16 bits, double buffering, 1 sample buffer, 4 samplers.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """

    def Depth(self, val: int) -> 'glcanvas.GLAttributes':
        """ Specifies number of bits for Z-buffer.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """

    def DoubleBuffer(self) -> 'glcanvas.GLAttributes':
        """ Requests using double buffering.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """

    def EndList(self) -> None:
        """ The set of attributes must end with this one; otherwise, the GPU may display nothing at all.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """

    def FrameBuffersRGB(self) -> 'glcanvas.GLAttributes':
        """ Used to request a frame buffer sRGB capable.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """

    def Level(self, val: int) -> 'glcanvas.GLAttributes':
        """ Specifies the framebuffer level.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """

    def MinAcumRGBA(self, mRed, mGreen, mBlue, mAlpha) -> 'glcanvas.GLAttributes':
        """ Specifies the minimal number of bits for each accumulator channel.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """

    def MinRGBA(self, mRed, mGreen, mBlue, mAlpha) -> 'glcanvas.GLAttributes':
        """ Specifies the minimal number of bits for each colour and alpha.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """

    def PlatformDefaults(self) -> 'glcanvas.GLAttributes':
        """ Set some typically needed attributes.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """

    def RGBA(self) -> 'glcanvas.GLAttributes':
        """ Use True colour instead of colour index rendering for each pixel.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """

    def SampleBuffers(self, val: int) -> 'glcanvas.GLAttributes':
        """ Use multi-sampling support (antialiasing).

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """

    def Samplers(self, val: int) -> 'glcanvas.GLAttributes':
        """ Specifies the number of samplers per pixel.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """

    def Stencil(self, val: int) -> 'glcanvas.GLAttributes':
        """ Specifies number of bits for stencil buffer.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """

    def Stereo(self) -> 'glcanvas.GLAttributes':
        """ Use stereoscopic display.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttributes.html
        """



class GLContextAttrs(GLAttribsBase):
    """ This class is used for setting context attributes.

        Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
    """
    def CompatibilityProfile(self) -> 'glcanvas.GLContextAttrs':
        """ Request a type of context with all OpenGL features from version 1.0 to the newest available by the GPU driver.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
        """

    def CoreProfile(self) -> 'glcanvas.GLContextAttrs':
        """ Request an OpenGL core profile for the context.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
        """

    def DebugCtx(self) -> 'glcanvas.GLContextAttrs':
        """ Request debugging functionality.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
        """

    def ES2(self) -> 'glcanvas.GLContextAttrs':
        """ Request an ES or ES2 (âEmbedded Subsystemâ) context.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
        """

    def EndList(self) -> None:
        """ The set of attributes must end with this one; otherwise, the GPU may display nothing at all.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
        """

    def ForwardCompatible(self) -> 'glcanvas.GLContextAttrs':
        """ Request a forward-compatible context.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
        """

    def LoseOnReset(self) -> 'glcanvas.GLContextAttrs':
        """ With robustness enabled, if graphics reset happens, all context state is lost.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
        """

    def MajorVersion(self, val: int) -> 'glcanvas.GLContextAttrs':
        """ Request specific OpenGL core major version number (>= 3).

            Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
        """

    def MinorVersion(self, val: int) -> 'glcanvas.GLContextAttrs':
        """ Request specific OpenGL core minor version number.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
        """

    def NoResetNotify(self) -> 'glcanvas.GLContextAttrs':
        """ With robustness enabled, never deliver notification of reset events.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
        """

    def OGLVersion(self, vmayor, vminor) -> 'glcanvas.GLContextAttrs':
        """ An easy way of requesting an OpenGL version.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
        """

    def PlatformDefaults(self) -> 'glcanvas.GLContextAttrs':
        """ Set platform specific defaults.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
        """

    def ReleaseFlush(self, val: int=1) -> 'glcanvas.GLContextAttrs':
        """ Request OpenGL to avoid or not flushing pending commands when the context is made no longer current (released).

            Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
        """

    def ResetIsolation(self) -> 'glcanvas.GLContextAttrs':
        """ Request OpenGL to protect other applications or shared contexts from reset side-effects.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
        """

    def Robust(self) -> 'glcanvas.GLContextAttrs':
        """ Request robustness, or how OpenGL handles out-of-bounds buffer object accesses and graphics reset notification behaviours.

            Source: https://docs.wxpython.org/wx.glcanvas.GLContextAttrs.html
        """



class GLAttribsBase:
    """ This is the base class for GLAttributes and GLContextAttrs.

        Source: https://docs.wxpython.org/wx.glcanvas.GLAttribsBase.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttribsBase.html
        """

    def AddAttribBits(self, searchVal, combineVal) -> None:
        """ Combine (bitwise wx.OR) a given value with the existing one, if any.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttribsBase.html
        """

    def AddAttribute(self, attribute: int) -> None:
        """ Adds an integer value to the list of attributes.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttribsBase.html
        """

    def GetSize(self) -> int:
        """ Returns the size of the internal list of attributes.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttribsBase.html
        """

    def NeedsARB(self) -> bool:
        """ Returns the current value of the ARB-flag.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttribsBase.html
        """

    def Reset(self) -> None:
        """ Delete contents and sets ARB-flag to False.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttribsBase.html
        """

    def SetNeedsARB(self, needsARB: bool=True) -> None:
        """ Sets the necessity of using special ARB-functions (e.g.

            Source: https://docs.wxpython.org/wx.glcanvas.GLAttribsBase.html
        """

    Size: int  # See GetSize



OR: int




# -*- coding: utf-8 -*-
from typing import Any, ContextManager, Optional, Union

class RibbonGalleryItem:
    """ Initialize self.  See help(type(self)) for accurate signature.

        Source: https://docs.wxpython.org/wx.lib.agw.ribbon.gallery.RibbonGalleryItem.html
    """
    def __init__(self) -> None:
        """ Initialize self.  See help(type(self)) for accurate signature.

            Source: https://docs.wxpython.org/wx.lib.agw.ribbon.gallery.RibbonGalleryItem.html
        """

    def GetBitmap(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.lib.agw.ribbon.gallery.RibbonGalleryItem.html
        """

    def GetClientData(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.lib.agw.ribbon.gallery.RibbonGalleryItem.html
        """

    def GetPosition(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.lib.agw.ribbon.gallery.RibbonGalleryItem.html
        """

    def IsVisible(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.lib.agw.ribbon.gallery.RibbonGalleryItem.html
        """

    def SetBitmap(self, bitmap) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.lib.agw.ribbon.gallery.RibbonGalleryItem.html
        """

    def SetClientData(self, data) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.lib.agw.ribbon.gallery.RibbonGalleryItem.html
        """

    def SetId(self, id) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.lib.agw.ribbon.gallery.RibbonGalleryItem.html
        """

    def SetIsVisible(self, visible) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.lib.agw.ribbon.gallery.RibbonGalleryItem.html
        """

    def SetPosition(self, x, y, size) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.lib.agw.ribbon.gallery.RibbonGalleryItem.html
        """






# -*- coding: utf-8 -*-
from typing import Any, ContextManager, Optional, Union

class RibbonButtonBarEvent(CommandEvent):
    """ Event used to indicate various actions relating to a button on a
RibbonButtonBar.

        Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBarEvent.html
    """
    def __init__(self, command_type=wxEVT_NULL, win_id=0, bar=None, button=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBarEvent.html
        """

    def GetBar(self) -> 'ribbon.RibbonButtonBar':
        """ Returns the bar which contains the button which the event relates to.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBarEvent.html
        """

    def GetButton(self) -> RibbonButtonBarButtonBase:
        """ Returns the button which the event relates to.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBarEvent.html
        """

    def PopupMenu(self, menu: 'Menu') -> bool:
        """ Display a popup menu as a result of this (dropdown clicked) event.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBarEvent.html
        """

    def SetBar(self, bar: 'ribbon.RibbonButtonBar') -> None:
        """ Sets the button bar relating to this event.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBarEvent.html
        """

    def SetButton(self, bar: RibbonButtonBarButtonBase) -> None:
        """ Sets the button relating to this event.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBarEvent.html
        """

    Bar: 'ribbon.RibbonButtonBar'  # See GetBar and SetBar
    Button: RibbonButtonBarButtonBase  # See GetButton and SetButton



class RibbonGalleryEvent(CommandEvent):
    """ Constructor.

        Source: https://docs.wxpython.org/wx.ribbon.RibbonGalleryEvent.html
    """
    def __init__(self, command_type=wxEVT_NULL, win_id=0, gallery=None, item=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGalleryEvent.html
        """

    def GetGallery(self) -> 'ribbon.RibbonGallery':
        """ Returns the gallery which the event relates to.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGalleryEvent.html
        """

    def GetGalleryItem(self) -> RibbonGalleryItem:
        """ Returns the gallery item which the event relates to, or None if it does not relate to an item.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGalleryEvent.html
        """

    def SetGallery(self, gallery: 'ribbon.RibbonGallery') -> None:
        """ Sets the gallery relating to this event.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGalleryEvent.html
        """

    def SetGalleryItem(self, item: RibbonGalleryItem) -> None:
        """ Sets the gallery item relating to this event.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGalleryEvent.html
        """

    Gallery: 'ribbon.RibbonGallery'  # See GetGallery and SetGallery
    GalleryItem: RibbonGalleryItem  # See GetGalleryItem and SetGalleryItem



class RibbonPanelEvent(CommandEvent):
    """ Event used to indicate various actions relating to a RibbonPanel.

        Source: https://docs.wxpython.org/wx.ribbon.RibbonPanelEvent.html
    """
    def __init__(self, command_type=wxEVT_NULL, win_id=0, panel=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanelEvent.html
        """

    def GetPanel(self) -> 'ribbon.RibbonPanel':
        """ Returns the panel relating to this event.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanelEvent.html
        """

    def SetPanel(self, page: 'ribbon.RibbonPanel') -> None:
        """ Sets the page relating to this event.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanelEvent.html
        """

    Panel: 'ribbon.RibbonPanel'  # See GetPanel and SetPanel



class RibbonToolBarEvent(CommandEvent):
    """ command_type (wx.EventType) â 

        Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBarEvent.html
    """
    def __init__(self, command_type=wxEVT_NULL, win_id=0, bar=None) -> None:
        """ command_type (wx.EventType) â

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBarEvent.html
        """

    def GetBar(self) -> 'ribbon.RibbonToolBar':
        """ wx.ribbon.RibbonToolBar

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBarEvent.html
        """

    def PopupMenu(self, menu: 'Menu') -> bool:
        """ menu (wx.Menu) â

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBarEvent.html
        """

    def SetBar(self, bar: 'ribbon.RibbonToolBar') -> None:
        """ bar (wx.ribbon.RibbonToolBar) â

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBarEvent.html
        """

    Bar: 'ribbon.RibbonToolBar'  # See GetBar and SetBar



class RibbonControl(Control):
    """ RibbonControl serves as a base class for all controls which share
the ribbon characteristics of having a ribbon art provider, and
(optionally) non-continuous resizing.

        Source: https://docs.wxpython.org/wx.ribbon.RibbonControl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonControl.html
        """

    def DoGetNextLargerSize(self, direction, relative_to) -> Size:
        """ Implementation of GetNextLargerSize .

            Source: https://docs.wxpython.org/wx.ribbon.RibbonControl.html
        """

    def DoGetNextSmallerSize(self, direction, relative_to) -> Size:
        """ Implementation of GetNextSmallerSize .

            Source: https://docs.wxpython.org/wx.ribbon.RibbonControl.html
        """

    def GetAncestorRibbonBar(self) -> 'ribbon.RibbonBar':
        """ Get the first ancestor which is a   wx.ribbon.RibbonBar  (or derived) or None if not having such parent.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonControl.html
        """

    def GetArtProvider(self) -> 'ribbon.RibbonArtProvider':
        """ Get the art provider to be used.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonControl.html
        """

    def GetBestSizeForParentSize(self, parentSize: Union[tuple[int, int], 'Size']) -> Size:
        """ Finds the best width and height given the parentâs width and height.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonControl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> VisualAttributes:
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ribbon.RibbonControl.html
        """

    def GetNextLargerSize(self, *args, **kw) -> Size:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonControl.html
        """

    def GetNextSmallerSize(self, *args, **kw) -> Size:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonControl.html
        """

    def IsSizingContinuous(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.ribbon.RibbonControl.html
        """

    def Realise(self) -> bool:
        """ Alias for Realize .

            Source: https://docs.wxpython.org/wx.ribbon.RibbonControl.html
        """

    def Realize(self) -> bool:
        """ Perform initial size and layout calculations after children have been added, and/or realize children.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonControl.html
        """

    def SetArtProvider(self, art: 'ribbon.RibbonArtProvider') -> None:
        """ Set the art provider to be used.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonControl.html
        """

    AncestorRibbonBar: 'ribbon.RibbonBar'  # See GetAncestorRibbonBar
    ArtProvider: 'ribbon.RibbonArtProvider'  # See GetArtProvider and SetArtProvider



RIBBON_PANEL_FLEXIBLE: int

class RibbonBarEvent(NotifyEvent):
    """ Event used to indicate various actions relating to a RibbonBar.

        Source: https://docs.wxpython.org/wx.ribbon.RibbonBarEvent.html
    """
    def __init__(self, command_type=wxEVT_NULL, win_id=0, page=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBarEvent.html
        """

    def GetPage(self) -> 'ribbon.RibbonPage':
        """ Returns the page being changed to, or being clicked on.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBarEvent.html
        """

    def SetPage(self, page: 'ribbon.RibbonPage') -> None:
        """ Sets the page relating to this event.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBarEvent.html
        """

    Page: 'ribbon.RibbonPage'  # See GetPage and SetPage



class RibbonButtonBar(RibbonControl):
    """ A ribbon button bar is similar to a traditional toolbar.

        Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def AddButton(self, *args, **kw) -> RibbonButtonBarButtonBase:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def AddDropdownButton(self, button_id, label, bitmap, help_string="") -> RibbonButtonBarButtonBase:
        """ Add a dropdown button to the button bar (simple version).

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def AddHybridButton(self, button_id, label, bitmap, help_string="") -> RibbonButtonBarButtonBase:
        """ Add a hybrid button to the button bar (simple version).

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def AddToggleButton(self, button_id, label, bitmap, help_string="") -> RibbonButtonBarButtonBase:
        """ Add a toggle button to the button bar (simple version).

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def ClearButtons(self) -> None:
        """ Delete all buttons from the button bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0) -> bool:
        """ Create a button bar in two-step button bar construction.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def DeleteButton(self, button_id: int) -> bool:
        """ Delete a single button from the button bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def EnableButton(self, button_id, enable=True) -> None:
        """ Enable or disable a single button on the bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def GetActiveItem(self) -> RibbonButtonBarButtonBase:
        """ Returns the active item of the button bar or None if there is none.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def GetButtonCount(self) -> int:
        """ Returns the number of buttons in this button bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> VisualAttributes:
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def GetHoveredItem(self) -> RibbonButtonBarButtonBase:
        """ Returns the hovered item of the button bar or None if there is none.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def GetItem(self, n: int) -> RibbonButtonBarButtonBase:
        """ Returns the N-th button of the bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def GetItemById(self, id: int) -> RibbonButtonBarButtonBase:
        """ Returns the first button having a given id or None if none matches.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def GetItemClientData(self, item: RibbonButtonBarButtonBase) -> ClientData:
        """ Get the client object associated with a button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def GetItemId(self, item: RibbonButtonBarButtonBase) -> int:
        """ Returns the id of a button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def GetItemRect(self, button_id: int) -> Rect:
        """ Returns the itemsâs rect with coordinates relative to the button barâs parent, or a default-constructed rect if the tool is not found.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def GetShowToolTipsForDisabled(self) -> bool:
        """ Sets whether tooltips should be shown for disabled buttons or not.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def InsertButton(self, *args, **kw) -> RibbonButtonBarButtonBase:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def InsertDropdownButton(self, pos, button_id, label, bitmap, help_string="") -> RibbonButtonBarButtonBase:
        """ Inserts a dropdown button to the button bar (simple version) at the given position.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def InsertHybridButton(self, pos, button_id, label, bitmap, help_string="") -> RibbonButtonBarButtonBase:
        """ Inserts a hybrid button to the button bar (simple version) at the given position.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def InsertToggleButton(self, pos, button_id, label, bitmap, help_string="") -> RibbonButtonBarButtonBase:
        """ Inserts a toggle button to the button bar (simple version) at the given position.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def Realize(self) -> bool:
        """ Calculate button layouts and positions.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def SetButtonIcon(self, button_id, bitmap, bitmap_small=NullBitmap, bitmap_disabled=NullBitmap, bitmap_small_disabled=NullBitmap) -> None:
        """ Changes the bitmap of an existing button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def SetButtonMaxSizeClass(self, button_id, max_size_class) -> None:
        """ Sets the maximum size class of a ribbon button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def SetButtonMinSizeClass(self, button_id, min_size_class) -> None:
        """ Sets the minimum size class of a ribbon button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def SetButtonText(self, button_id, label) -> None:
        """ Changes the label text of an existing button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def SetButtonTextMinWidth(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def SetItemClientData(self, item, data) -> None:
        """ Set the client object associated with a button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def SetShowToolTipsForDisabled(self, show: bool) -> None:
        """ Indicates whether tooltips are shown for disabled buttons.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    def ToggleButton(self, button_id, checked) -> None:
        """ Set a toggle button to the checked or unchecked state.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonButtonBar.html
        """

    ActiveItem: RibbonButtonBarButtonBase  # See GetActiveItem
    ButtonCount: int  # See GetButtonCount
    HoveredItem: RibbonButtonBarButtonBase  # See GetHoveredItem
    ShowToolTipsForDisabled: bool  # See GetShowToolTipsForDisabled and SetShowToolTipsForDisabled



EVT_RIBBONBUTTONBAR_CLICKED: int  # Triggered when the normal (non-dropdown) region of a button on the button bar is clicked.

EVT_RIBBONBUTTONBAR_DROPDOWN_CLICKED: int  # Triggered when the dropdown region of a button on the button bar is clicked. wx.ribbon.RibbonButtonBarEvent.PopupMenu   should be called by the event handler if it wants to display a popup menu (which is what most dropdown buttons should be doing). ^^

RIBBON_BUTTONBAR_BUTTON_SMALL: int

RIBBON_BUTTONBAR_BUTTON_MEDIUM: int

RIBBON_BUTTONBAR_BUTTON_LARGE: int

class RibbonBar(RibbonControl):
    """ Top-level control in a ribbon user interface.

        Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def AddPageHighlight(self, page, highlight=True) -> None:
        """ Highlight the specified tab.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def ArePanelsShown(self) -> bool:
        """ Indicates whether the panel area of the ribbon bar is shown.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def ClearPages(self) -> None:
        """ Delete all pages from the ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=RIBBON_BAR_DEFAULT_STYLE) -> bool:
        """ Create a ribbon bar in two-step ribbon bar construction.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def DeletePage(self, n: int) -> None:
        """ Delete a single page from this ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def DismissExpandedPanel(self) -> bool:
        """ Dismiss the expanded panel of the currently active page.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def GetActivePage(self) -> int:
        """ Get the index of the active page.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> VisualAttributes:
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def GetDisplayMode(self) -> 'ribbon.RibbonDisplayMode':
        """ Returns the current display mode of the panel area.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def GetPage(self, n: int) -> 'ribbon.RibbonPage':
        """ Get a page by index.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def GetPageCount(self) -> int:
        """ Get the number of pages in this bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def GetPageNumber(self, page: 'ribbon.RibbonPage') -> int:
        """ Returns the number for a given ribbon bar page.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def HidePage(self, page: int) -> None:
        """ Hides the tab for a given page.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def HidePanels(self) -> None:
        """ Hides the panel area of the ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def IsPageHighlighted(self, page: int) -> bool:
        """ Indicates whether a tab is currently highlighted.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def IsPageShown(self, page: int) -> bool:
        """ Indicates whether the tab for the given page is shown to the user or not.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def Realize(self) -> bool:
        """ Perform initial layout and size calculations of the bar and its children.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def RemovePageHighlight(self, page: int) -> None:
        """ Changes a tab to not be highlighted.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def SetActivePage(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def SetArtProvider(self, art: 'ribbon.RibbonArtProvider') -> None:
        """ Set the art provider to be used be the ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def SetTabCtrlMargins(self, left, right) -> None:
        """ Set the margin widths (in pixels) on the left and right sides of the tab bar region of the ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def ShowPage(self, page, show_tab=True) -> None:
        """ Show or hide the tab for a given page.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    def ShowPanels(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonBar.html
        """

    ActivePage: int  # See GetActivePage and SetActivePage
    DisplayMode: 'ribbon.RibbonDisplayMode'  # See GetDisplayMode
    PageCount: int  # See GetPageCount



RIBBON_BAR_DEFAULT_STYLE: int  # Defined as wx.ribbon.RIBBON_BAR_FLOW_HORIZONTAL | wx.ribbon.RIBBON_BAR_SHOW_PAGE_LABELS | wx.ribbon.RIBBON_BAR_SHOW_PANEL_EXT_BUTTONS | wx.ribbon.RIBBON_BAR_SHOW_TOGGLE_BUTTON | wx.ribbon.RIBBON_BAR_SHOW_HELP_BUTTON.

RIBBON_BAR_FOLDBAR_STYLE: int  # Defined as wx.ribbon.RIBBON_BAR_FLOW_VERTICAL | wx.ribbon.RIBBON_BAR_SHOW_PAGE_ICONS | wx.ribbon.RIBBON_BAR_SHOW_PANEL_EXT_BUTTONS | wx.ribbon.RIBBON_BAR_SHOW_PANEL_MINIMISE_BUTTONS

RIBBON_BAR_SHOW_PAGE_LABELS: int  # Causes labels to be shown on the tabs in the ribbon bar.

RIBBON_BAR_SHOW_PAGE_ICONS: int  # Causes icons to be shown on the tabs in the ribbon bar.

RIBBON_BAR_FLOW_HORIZONTAL: int  # Causes panels within pages to stack horizontally.

RIBBON_BAR_FLOW_VERTICAL: int  # Causes panels within pages to stack vertically.

RIBBON_BAR_SHOW_PANEL_EXT_BUTTONS: int  # Causes extension buttons to be shown on panels (where the panel has such a button).

RIBBON_BAR_SHOW_PANEL_MINIMISE_BUTTONS: int  # Causes minimise buttons to be shown on panels (where the panel has such a button).

RIBBON_BAR_SHOW_TOGGLE_BUTTON: int  # Causes a toggle button to appear on the ribbon bar at top-right corner. This style is new since wxWidgets 2.9.5.

RIBBON_BAR_SHOW_HELP_BUTTON: int  # Causes a help button to appear on the ribbon bar at the top-right corner. This style is new since wxWidgets 2.9.5. ^^

EVT_RIBBONBAR_PAGE_CHANGED: int  # Triggered after the transition from one page being active to a different page being active.

EVT_RIBBONBAR_PAGE_CHANGING: int  # Triggered prior to the transition from one page being active to a different page being active, and can veto the change.

EVT_RIBBONBAR_TAB_MIDDLE_DOWN: int  # Triggered when the middle mouse button is pressed on a tab.

EVT_RIBBONBAR_TAB_MIDDLE_UP: int  # Triggered when the middle mouse button is released on a tab.

EVT_RIBBONBAR_TAB_RIGHT_DOWN: int  # Triggered when the right mouse button is pressed on a tab.

EVT_RIBBONBAR_TAB_RIGHT_UP: int  # Triggered when the right mouse button is released on a tab.

EVT_RIBBONBAR_TAB_LEFT_DCLICK: int  # Triggered when the left mouse button is double clicked on a tab.

EVT_RIBBONBAR_TOGGLED: int  # Triggered when the button triggering the ribbon bar is clicked. This event is new since wxWidgets 2.9.5.

EVT_RIBBONBAR_HELP_CLICK: int  # Triggered when the help button is clicked. This even is new since wxWidgets 2.9.5. ^^

class RibbonGallery(RibbonControl):
    """ A ribbon gallery is like a ListBox, but for bitmaps rather than
strings.

        Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def Append(self, *args, **kw) -> RibbonGalleryItem:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def Clear(self) -> None:
        """ Remove all items from the gallery.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0) -> bool:
        """ Create a gallery in two-step gallery construction.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def EnsureVisible(self, item: RibbonGalleryItem) -> None:
        """ Scroll the gallery to ensure that the given item is visible.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def GetActiveItem(self) -> RibbonGalleryItem:
        """ Get the currently active item, or None if there is none.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> VisualAttributes:
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def GetCount(self) -> int:
        """ Get the number of items in the gallery.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def GetDownButtonState(self) -> 'ribbon.RibbonGalleryButtonState':
        """ Get the state of the scroll down button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def GetExtensionButtonState(self) -> 'ribbon.RibbonGalleryButtonState':
        """ Get the state of the âextensionâ button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def GetHoveredItem(self) -> RibbonGalleryItem:
        """ Get the currently hovered item, or None if there is none.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def GetItem(self, n: int) -> RibbonGalleryItem:
        """ Get an item by index.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def GetItemClientData(self, item: RibbonGalleryItem) -> ClientData:
        """ Get the client object associated with a gallery item.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def GetSelection(self) -> RibbonGalleryItem:
        """ Get the currently selected item, or None if there is none.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def GetUpButtonState(self) -> 'ribbon.RibbonGalleryButtonState':
        """ Get the state of the scroll up button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def IsEmpty(self) -> bool:
        """ Query if the gallery has no items in it.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def IsHovered(self) -> bool:
        """ Query is the mouse is currently hovered over the gallery.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def ScrollLines(self, lines: int) -> bool:
        """ Scroll the gallery contents by some amount.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def ScrollPixels(self, pixels: int) -> bool:
        """ Scroll the gallery contents by some fine-grained amount.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def SetItemClientData(self, item, data) -> None:
        """ Set the client object associated with a gallery item.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    def SetSelection(self, item: RibbonGalleryItem) -> None:
        """ Set the selection to the given item, or removes the selection if item  == None.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonGallery.html
        """

    ActiveItem: RibbonGalleryItem  # See GetActiveItem
    Count: int  # See GetCount
    DownButtonState: 'ribbon.RibbonGalleryButtonState'  # See GetDownButtonState
    ExtensionButtonState: 'ribbon.RibbonGalleryButtonState'  # See GetExtensionButtonState
    HoveredItem: RibbonGalleryItem  # See GetHoveredItem
    Selection: RibbonGalleryItem  # See GetSelection and SetSelection
    UpButtonState: 'ribbon.RibbonGalleryButtonState'  # See GetUpButtonState



EVT_RIBBONGALLERY_SELECTED: int  # Triggered when the user selects an item from the gallery. Note that the ID is that of the gallery, not of the item.

EVT_RIBBONGALLERY_CLICKED: int  # Similar to EVT_RIBBONGALLERY_SELECTED but triggered every time a gallery item is clicked, even if it is already selected. Note that the ID of the event is that of the gallery, not of the item, just as above. This event is available since wxWidgets 2.9.2.

EVT_RIBBONGALLERY_HOVER_CHANGED: int  # Triggered when the item being hovered over by the user changes. The item in the event will be the new item being hovered, or None if there is no longer an item being hovered. Note that the ID is that of the gallery, not of the item. ^^ ^^

class RibbonPanel(RibbonControl):
    """ Serves as a container for a group of (ribbon) controls.

        Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
        """

    def CanAutoMinimise(self) -> bool:
        """ Query if the panel can automatically minimise itself at small sizes.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
        """

    def Create(self, parent, id=ID_ANY, label="", icon=NullBitmap, pos=DefaultPosition, size=DefaultSize, style=RIBBON_PANEL_DEFAULT_STYLE) -> bool:
        """ Create a ribbon panel in two-step ribbon panel construction.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> VisualAttributes:
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
        """

    def GetExpandedDummy(self) -> 'ribbon.RibbonPanel':
        """ Get the dummy panel of an expanded panel.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
        """

    def GetExpandedPanel(self) -> 'ribbon.RibbonPanel':
        """ Get the expanded panel of a dummy panel.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
        """

    def GetMinimisedIcon(self) -> Bitmap:
        """ Get the bitmap to be used in place of the panel children when it is minimised.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
        """

    def HasExtButton(self) -> bool:
        """ Test if the panel has an extension button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
        """

    def HideExpanded(self) -> bool:
        """ Hide the panelâs external expansion.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
        """

    def IsExtButtonHovered(self) -> bool:
        """ Query if the mouse is currently hovered over the extension button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
        """

    def IsHovered(self) -> bool:
        """ Query is the mouse is currently hovered over the panel.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
        """

    def IsMinimised(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
        """

    def Realize(self) -> bool:
        """ Realize all children of the panel.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
        """

    def SetArtProvider(self, art: 'ribbon.RibbonArtProvider') -> None:
        """ Set the art provider to be used.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
        """

    def ShowExpanded(self) -> bool:
        """ Show the panel externally expanded.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPanel.html
        """

    ExpandedDummy: 'ribbon.RibbonPanel'  # See GetExpandedDummy
    ExpandedPanel: 'ribbon.RibbonPanel'  # See GetExpandedPanel
    MinimisedIcon: Bitmap  # See GetMinimisedIcon



RIBBON_PANEL_DEFAULT_STYLE: int  # Defined as no other flags set.

RIBBON_PANEL_NO_AUTO_MINIMISE: int  # Prevents the panel from automatically minimising to conserve screen space.

RIBBON_PANEL_EXT_BUTTON: int  # Causes an extension button to be shown in the panelâs chrome (if the bar in which it is contained has wx.ribbon.RIBBON_BAR_SHOW_PANEL_EXT_BUTTONS set). The behaviour of this button is application controlled, but typically will show an extended drop-down menu relating to the panel.

RIBBON_PANEL_MINIMISE_BUTTON: int  # Causes a (de)minimise button to be shown in the panelâs chrome (if the bar in which it is contained has the wx.ribbon.RIBBON_BAR_SHOW_PANEL_MINIMISE_BUTTONS style set). This flag is typically combined with wx.ribbon.RIBBON_PANEL_NO_AUTO_MINIMISE to make a panel which the user always has manual control over when it minimises.

RIBBON_PANEL_STRETCH: int  # Stretches a single panel to fit the parent page.

EVT_RIBBONPANEL_EXTBUTTON_ACTIVATED: int  # Triggered when the user activate the panel extension button. ^^

class RibbonToolBar(RibbonControl):
    """ A ribbon tool bar is similar to a traditional toolbar which has no
labels.

        Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def AddDropdownTool(self, tool_id, bitmap, help_string="") -> RibbonToolBarToolBase:
        """ Add a dropdown tool to the tool bar (simple version).

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def AddHybridTool(self, tool_id, bitmap, help_string="") -> RibbonToolBarToolBase:
        """ Add a hybrid tool to the tool bar (simple version).

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def AddSeparator(self) -> RibbonToolBarToolBase:
        """ Add a separator to the tool bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def AddToggleTool(self, tool_id, bitmap, help_string) -> RibbonToolBarToolBase:
        """ Add a toggle tool to the tool bar (simple version).

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def AddTool(self, *args, **kw) -> RibbonToolBarToolBase:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def ClearTools(self) -> None:
        """ Deletes all the tools in the toolbar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0) -> bool:
        """ Create a tool bar in two-step tool bar construction.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def DeleteTool(self, tool_id: int) -> bool:
        """ Removes the specified tool from the toolbar and deletes it.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def DeleteToolByPos(self, pos: int) -> bool:
        """ This function behaves like DeleteTool   but it deletes the tool at the specified position and not the one with the given id.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def EnableTool(self, tool_id, enable=True) -> None:
        """ Enable or disable a single tool on the bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def FindById(self, tool_id: int) -> RibbonToolBarToolBase:
        """ Returns a pointer to the tool opaque structure by id  or None if no corresponding tool is found.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def GetActiveTool(self) -> RibbonToolBarToolBase:
        """ Returns the active item of the tool bar or None if there is none.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> VisualAttributes:
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def GetToolByPos(self, *args, **kw) -> RibbonToolBarToolBase:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def GetToolClientData(self, tool_id: int) -> PyUserData:
        """ Get any client data associated with the tool.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def GetToolCount(self) -> int:
        """ Returns the number of tools in the toolbar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def GetToolEnabled(self, tool_id: int) -> bool:
        """ Called to determine whether a tool is enabled (responds to user input).

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def GetToolHelpString(self, tool_id: int) -> str:
        """ Returns the help string for the given tool.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def GetToolId(self, tool: RibbonToolBarToolBase) -> int:
        """ Return the id associated to the tool opaque structure.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def GetToolKind(self, tool_id: int) -> 'ribbon.RibbonButtonKind':
        """ Return the kind of the given tool.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def GetToolPos(self, tool_id: int) -> int:
        """ Returns the tool position in the toolbar, or  NOT_FOUND   if the tool is not found.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def GetToolRect(self, tool_id: int) -> Rect:
        """ Returns the toolâs rect with coordinates relative to the toolbarâs parent, or a default-constructed rect if the tool is not found.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def GetToolState(self, tool_id: int) -> bool:
        """ Gets the on/off state of a toggle tool.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def InsertDropdownTool(self, pos, tool_id, bitmap, help_string="") -> RibbonToolBarToolBase:
        """ Insert a dropdown tool to the tool bar (simple version) as the specified position.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def InsertHybridTool(self, pos, tool_id, bitmap, help_string="") -> RibbonToolBarToolBase:
        """ Insert a hybrid tool to the tool bar (simple version) as the specified position.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def InsertSeparator(self, pos: int) -> RibbonToolBarToolBase:
        """ Insert a separator to the tool bar at the specified position.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def InsertToggleTool(self, pos, tool_id, bitmap, help_string="") -> RibbonToolBarToolBase:
        """ Insert a toggle tool to the tool bar (simple version) as the specified position.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def InsertTool(self, *args, **kw) -> RibbonToolBarToolBase:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def Realize(self) -> bool:
        """ Calculate tool layouts and positions.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def SetRows(self, nMin, nMax=-1) -> None:
        """ Set the number of rows to distribute tool groups over.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def SetToolClientData(self, tool_id, clientData) -> None:
        """ Sets the client data associated with the tool.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def SetToolDisabledBitmap(self, tool_id, bitmap) -> None:
        """ Sets the bitmap to be used by the tool with the given ID when the tool is in a disabled state.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def SetToolHelpString(self, tool_id, helpString) -> None:
        """ Sets the help string shown in tooltip for the given tool.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def SetToolNormalBitmap(self, tool_id, bitmap) -> None:
        """ Sets the bitmap to be used by the tool with the given ID.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    def ToggleTool(self, tool_id, checked) -> None:
        """ Set a toggle tool to the checked or unchecked state.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonToolBar.html
        """

    ActiveTool: RibbonToolBarToolBase  # See GetActiveTool
    ToolCount: int  # See GetToolCount



EVT_RIBBONTOOLBAR_CLICKED: int  # Triggered when the normal (non-dropdown) region of a tool on the tool bar is clicked.

EVT_RIBBONTOOLBAR_DROPDOWN_CLICKED: int  # Triggered when the dropdown region of a tool on the tool bar is clicked. wx.ribbon.RibbonToolBarEvent.PopupMenu   should be called by the event handler if it wants to display a popup menu (which is what most dropdown tools should be doing). ^^

class RibbonArtProvider:
    """ RibbonArtProvider is responsible for drawing all the components of
the ribbon interface.

        Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def Clone(self) -> 'ribbon.RibbonArtProvider':
        """ Create a new art provider which is a clone of this one.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawButtonBarBackground(self, dc, wnd, rect) -> None:
        """ Draw the background for a   wx.ribbon.RibbonButtonBar  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawButtonBarButton(self, dc, wnd, rect, kind, state, label, bitmap_large, bitmap_small) -> None:
        """ Draw a single button for a   wx.ribbon.RibbonButtonBar  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawGalleryBackground(self, dc, wnd, rect) -> None:
        """ Draw the background and chrome for a   wx.ribbon.RibbonGallery  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawGalleryItemBackground(self, dc, wnd, rect, item) -> None:
        """ Draw the background of a single item in a   wx.ribbon.RibbonGallery  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawHelpButton(self, dc, wnd, rect) -> None:
        """ Draw help button on   wx.ribbon.RibbonBar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawMinimisedPanel(self, dc, wnd, rect, bitmap) -> None:
        """ Draw a minimised ribbon panel.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawPageBackground(self, dc, wnd, rect) -> None:
        """ Draw the background of a ribbon page.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawPanelBackground(self, dc, wnd, rect) -> None:
        """ Draw the background and chrome for a ribbon panel.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawScrollButton(self, dc, wnd, rect, style) -> None:
        """ Draw a ribbon-style scroll button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawTab(self, dc, wnd, tab) -> None:
        """ Draw a single tab in the tab region of a ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawTabCtrlBackground(self, dc, wnd, rect) -> None:
        """ Draw the background of the tab region of a ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawTabSeparator(self, dc, wnd, rect, visibility) -> None:
        """ Draw a separator between two tabs in a ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawToggleButton(self, dc, wnd, rect, mode) -> None:
        """ Draw toggle button on   wx.ribbon.RibbonBar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawTool(self, dc, wnd, rect, bitmap, kind, state) -> None:
        """ Draw a single tool (for a   wx.ribbon.RibbonToolBar  control).

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawToolBarBackground(self, dc, wnd, rect) -> None:
        """ Draw the background for a   wx.ribbon.RibbonToolBar  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def DrawToolGroupBackground(self, dc, wnd, rect) -> None:
        """ Draw the background for a group of tools on a   wx.ribbon.RibbonToolBar  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetBarTabWidth(self, dc, wnd, label, bitmap, ideal, small_begin_need_separator, small_must_have_separator, minimum) -> None:
        """ Calculate the ideal and minimum width (in pixels) of a tab in a ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetBarToggleButtonArea(self, rect: 'Rect') -> Rect:
        """ Calculate the position and size of the ribbonâs toggle button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetButtonBarButtonSize(self, dc, wnd, kind, size, label, text_min_width, bitmap_size_large, bitmap_size_small, button_size, normal_region, dropdown_region) -> bool:
        """ Calculate the size of a button within a   wx.ribbon.RibbonButtonBar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetButtonBarButtonTextWidth(self, dc, label, kind, size) -> 'Coord':
        """ Gets the width of the string if it is used as a   wx.ribbon.RibbonButtonBar  button label.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetColor(self, id: int) -> Colour:
        """ id (int) â

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetColour(self, id: int) -> Colour:
        """ Get the value of a certain colour setting.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetColourScheme(self) -> tuple:
        """ Get the current colour scheme.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetFlags(self) -> int:
        """ Get the previously set style flags.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetFont(self, id: int) -> Font:
        """ Get the value of a certain font setting.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetGalleryClientSize(self, dc, wnd, size, client_offset, scroll_up_button, scroll_down_button, extension_button) -> Size:
        """ Calculate the client size of a   wx.ribbon.RibbonGallery  control for a given size.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetGallerySize(self, dc, wnd, client_size) -> Size:
        """ Calculate the size of a   wx.ribbon.RibbonGallery  control for a given client size.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetMetric(self, id: int) -> int:
        """ Get the value of a certain integer setting.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetMinimisedPanelMinimumSize(self, dc, wnd, desired_bitmap_size, expanded_panel_direction) -> Size:
        """ Calculate the size of a minimised ribbon panel.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetPageBackgroundRedrawArea(self, dc, wnd, page_old_size, page_new_size) -> Rect:
        """ Calculate the portion of a page background which needs to be redrawn when a page is resized.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetPanelClientSize(self, dc, wnd, size, client_offset) -> Size:
        """ Calculate the client size of a panel for a given overall size.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetPanelExtButtonArea(self, dc, wnd, rect) -> Rect:
        """ Calculate the position and size of the panel extension button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetPanelSize(self, dc, wnd, client_size, client_offset) -> Size:
        """ Calculate the size of a panel for a given client size.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetRibbonHelpButtonArea(self, rect: 'Rect') -> Rect:
        """ Calculate the position and size of the ribbonâs help button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetScrollButtonMinimumSize(self, dc, wnd, style) -> Size:
        """ Calculate the minimum size (in pixels) of a scroll button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetTabCtrlHeight(self, dc, wnd, pages) -> int:
        """ Calculate the height (in pixels) of the tab region of a ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def GetToolSize(self, dc, wnd, bitmap_size, kind, is_first, is_last, dropdown_region) -> Size:
        """ Calculate the size of a tool within a   wx.ribbon.RibbonToolBar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def SetColor(self, id, color) -> None:
        """ id (int) â

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def SetColour(self, id, colour) -> None:
        """ Set the value of a certain colour setting to the value colour.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def SetColourScheme(self, primary, secondary, tertiary) -> None:
        """ Set all applicable colour settings from a few base colours.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def SetFlags(self, flags: int) -> None:
        """ Set the style flags.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def SetFont(self, id, font) -> None:
        """ Set the value of a certain font setting to the value font.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    def SetMetric(self, id, new_val) -> None:
        """ Set the value of a certain integer setting to the value new_val.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonArtProvider.html
        """

    Flags: int  # See GetFlags and SetFlags



RIBBON_BUTTONBAR_BUTTON_DISABLED: int

RIBBON_ART_GALLERY_BITMAP_PADDING_RIGHT_SIZE: int

RIBBON_ART_GALLERY_BITMAP_PADDING_TOP_SIZE: int

RIBBON_ART_GALLERY_BITMAP_PADDING_BOTTOM_SIZE: int

class RibbonPage(RibbonControl):
    """ Container for related ribbon panels, and a tab within a ribbon bar.

        Source: https://docs.wxpython.org/wx.ribbon.RibbonPage.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPage.html
        """

    def AdjustRectToIncludeScrollButtons(self, rect: 'Rect') -> None:
        """ Expand a rectangle of the page to include external scroll buttons (if any).

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPage.html
        """

    def Create(self, parent, id=ID_ANY, label="", icon=NullBitmap, style=0) -> bool:
        """ Create a ribbon page in two-step ribbon page construction.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPage.html
        """

    def DismissExpandedPanel(self) -> bool:
        """ Dismiss the current externally expanded panel, if there is one.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPage.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> VisualAttributes:
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPage.html
        """

    def GetIcon(self) -> Bitmap:
        """ Get the icon used for the page in the ribbon bar tab area (only displayed if the ribbon bar is actually showing icons).

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPage.html
        """

    def GetMajorAxis(self) -> 'Orientation':
        """ Get the direction in which ribbon panels are stacked within the page.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPage.html
        """

    def Realize(self) -> bool:
        """ Perform a full re-layout of all panels on the page.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPage.html
        """

    def ScrollLines(self, lines: int) -> bool:
        """ Scroll the page by some amount up / down / left / right.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPage.html
        """

    def ScrollPixels(self, pixels: int) -> bool:
        """ Scroll the page by a set number of pixels up / down / left / right.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPage.html
        """

    def ScrollSections(self, sections: int) -> bool:
        """ Scroll the page by an entire child section.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPage.html
        """

    def SetArtProvider(self, art: 'ribbon.RibbonArtProvider') -> None:
        """ Set the art provider to be used.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPage.html
        """

    def SetSizeWithScrollButtonAdjustment(self, x, y, width, height) -> None:
        """ Set the size of the page and the external scroll buttons (if any).

            Source: https://docs.wxpython.org/wx.ribbon.RibbonPage.html
        """

    Icon: Bitmap  # See GetIcon
    MajorAxis: 'Orientation'  # See GetMajorAxis



HORIZONTAL: int

VERTICAL: int

BOTH: int

RIBBON_BUTTON_NORMAL: int

RIBBON_BUTTON_DROPDOWN: int

RIBBON_BUTTON_HYBRID: int

RIBBON_BUTTON_TOGGLE: int

RIBBON_BUTTONBAR_BUTTON_SIZE_MASK: int

RIBBON_BUTTONBAR_BUTTON_NORMAL_HOVERED: int

RIBBON_BUTTONBAR_BUTTON_DROPDOWN_HOVERED: int

RIBBON_BUTTONBAR_BUTTON_HOVER_MASK: int

RIBBON_BUTTONBAR_BUTTON_NORMAL_ACTIVE: int

RIBBON_BUTTONBAR_BUTTON_DROPDOWN_ACTIVE: int

RIBBON_BUTTONBAR_BUTTON_ACTIVE_MASK: int

RIBBON_BUTTONBAR_BUTTON_TOGGLED: int

RIBBON_BUTTONBAR_BUTTON_STATE_MASK: int

RIBBON_BAR_PINNED: int

RIBBON_BAR_MINIMIZED: int

RIBBON_BAR_EXPANDED: int

RIBBON_GALLERY_BUTTON_NORMAL: int

RIBBON_GALLERY_BUTTON_HOVERED: int

RIBBON_GALLERY_BUTTON_ACTIVE: int

RIBBON_GALLERY_BUTTON_DISABLED: int

class RibbonAUIArtProvider(RibbonMSWArtProvider):
    """ Create a new art provider which is a clone of this one.

        Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def Clone(self) -> 'ribbon.RibbonArtProvider':
        """ Create a new art provider which is a clone of this one.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def DrawButtonBarBackground(self, dc, wnd, rect) -> None:
        """ Draw the background for a   wx.ribbon.RibbonButtonBar  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def DrawButtonBarButton(self, dc, wnd, rect, kind, state, label, bitmap_large, bitmap_small) -> None:
        """ Draw a single button for a   wx.ribbon.RibbonButtonBar  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def DrawGalleryBackground(self, dc, wnd, rect) -> None:
        """ Draw the background and chrome for a   wx.ribbon.RibbonGallery  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def DrawGalleryItemBackground(self, dc, wnd, rect, item) -> None:
        """ Draw the background of a single item in a   wx.ribbon.RibbonGallery  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def DrawMinimisedPanel(self, dc, wnd, rect, bitmap) -> None:
        """ Draw a minimised ribbon panel.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def DrawPageBackground(self, dc, wnd, rect) -> None:
        """ Draw the background of a ribbon page.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def DrawPanelBackground(self, dc, wnd, rect) -> None:
        """ Draw the background and chrome for a ribbon panel.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def DrawScrollButton(self, dc, wnd, rect, style) -> None:
        """ Draw a ribbon-style scroll button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def DrawTab(self, dc, wnd, tab) -> None:
        """ Draw a single tab in the tab region of a ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def DrawTabCtrlBackground(self, dc, wnd, rect) -> None:
        """ Draw the background of the tab region of a ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def DrawTabSeparator(self, dc, wnd, rect, visibility) -> None:
        """ Draw a separator between two tabs in a ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def DrawTool(self, dc, wnd, rect, bitmap, kind, state) -> None:
        """ Draw a single tool (for a   wx.ribbon.RibbonToolBar  control).

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def DrawToolBarBackground(self, dc, wnd, rect) -> None:
        """ Draw the background for a   wx.ribbon.RibbonToolBar  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def DrawToolGroupBackground(self, dc, wnd, rect) -> None:
        """ Draw the background for a group of tools on a   wx.ribbon.RibbonToolBar  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def GetBarTabWidth(self, dc, wnd, label, bitmap, ideal, small_begin_need_separator, small_must_have_separator, minimum) -> None:
        """ Calculate the ideal and minimum width (in pixels) of a tab in a ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def GetColour(self, id: int) -> Colour:
        """ Get the value of a certain colour setting.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def GetPanelClientSize(self, dc, wnd, size, client_offset) -> Size:
        """ Calculate the client size of a panel for a given overall size.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def GetPanelExtButtonArea(self, dc, wnd, rect) -> Rect:
        """ Calculate the position and size of the panel extension button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def GetPanelSize(self, dc, wnd, client_size, client_offset) -> Size:
        """ Calculate the size of a panel for a given client size.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def GetScrollButtonMinimumSize(self, dc, wnd, style) -> Size:
        """ Calculate the minimum size (in pixels) of a scroll button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def GetTabCtrlHeight(self, dc, wnd, pages) -> int:
        """ Calculate the height (in pixels) of the tab region of a ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def SetColour(self, id, colour) -> None:
        """ Set the value of a certain colour setting to the value colour.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def SetColourScheme(self, primary, secondary, tertiary) -> None:
        """ Set all applicable colour settings from a few base colours.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """

    def SetFont(self, id, font) -> None:
        """ Set the value of a certain font setting to the value font.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonAUIArtProvider.html
        """



class RibbonMSWArtProvider(RibbonArtProvider):
    """ set_colour_scheme (bool) â 

        Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
    """
    def __init__(self, set_colour_scheme: bool=True) -> None:
        """ set_colour_scheme (bool) â

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def Clone(self) -> 'ribbon.RibbonArtProvider':
        """ Create a new art provider which is a clone of this one.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawButtonBarBackground(self, dc, wnd, rect) -> None:
        """ Draw the background for a   wx.ribbon.RibbonButtonBar  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawButtonBarButton(self, dc, wnd, rect, kind, state, label, bitmap_large, bitmap_small) -> None:
        """ Draw a single button for a   wx.ribbon.RibbonButtonBar  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawGalleryBackground(self, dc, wnd, rect) -> None:
        """ Draw the background and chrome for a   wx.ribbon.RibbonGallery  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawGalleryItemBackground(self, dc, wnd, rect, item) -> None:
        """ Draw the background of a single item in a   wx.ribbon.RibbonGallery  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawHelpButton(self, dc, wnd, rect) -> None:
        """ Draw help button on   wx.ribbon.RibbonBar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawMinimisedPanel(self, dc, wnd, rect, bitmap) -> None:
        """ Draw a minimised ribbon panel.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawPageBackground(self, dc, wnd, rect) -> None:
        """ Draw the background of a ribbon page.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawPanelBackground(self, dc, wnd, rect) -> None:
        """ Draw the background and chrome for a ribbon panel.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawScrollButton(self, dc, wnd, rect, style) -> None:
        """ Draw a ribbon-style scroll button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawTab(self, dc, wnd, tab) -> None:
        """ Draw a single tab in the tab region of a ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawTabCtrlBackground(self, dc, wnd, rect) -> None:
        """ Draw the background of the tab region of a ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawTabSeparator(self, dc, wnd, rect, visibility) -> None:
        """ Draw a separator between two tabs in a ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawToggleButton(self, dc, wnd, rect, mode) -> None:
        """ Draw toggle button on   wx.ribbon.RibbonBar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawTool(self, dc, wnd, rect, bitmap, kind, state) -> None:
        """ Draw a single tool (for a   wx.ribbon.RibbonToolBar  control).

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawToolBarBackground(self, dc, wnd, rect) -> None:
        """ Draw the background for a   wx.ribbon.RibbonToolBar  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def DrawToolGroupBackground(self, dc, wnd, rect) -> None:
        """ Draw the background for a group of tools on a   wx.ribbon.RibbonToolBar  control.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetBarTabWidth(self, dc, wnd, label, bitmap, ideal, small_begin_need_separator, small_must_have_separator, minimum) -> None:
        """ Calculate the ideal and minimum width (in pixels) of a tab in a ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetBarToggleButtonArea(self, rect: 'Rect') -> Rect:
        """ Calculate the position and size of the ribbonâs toggle button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetButtonBarButtonSize(self, dc, wnd, kind, size, label, text_min_width, bitmap_size_large, bitmap_size_small, button_size, normal_region, dropdown_region) -> bool:
        """ Calculate the size of a button within a   wx.ribbon.RibbonButtonBar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetButtonBarButtonTextWidth(self, dc, label, kind, size) -> 'Coord':
        """ Gets the width of the string if it is used as a   wx.ribbon.RibbonButtonBar  button label.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetColour(self, id: int) -> Colour:
        """ Get the value of a certain colour setting.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetColourScheme(self) -> tuple:
        """ Get the current colour scheme.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetFlags(self) -> int:
        """ Get the previously set style flags.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetFont(self, id: int) -> Font:
        """ Get the value of a certain font setting.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetGalleryClientSize(self, dc, wnd, size, client_offset, scroll_up_button, scroll_down_button, extension_button) -> Size:
        """ Calculate the client size of a   wx.ribbon.RibbonGallery  control for a given size.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetGallerySize(self, dc, wnd, client_size) -> Size:
        """ Calculate the size of a   wx.ribbon.RibbonGallery  control for a given client size.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetMetric(self, id: int) -> int:
        """ Get the value of a certain integer setting.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetMinimisedPanelMinimumSize(self, dc, wnd, desired_bitmap_size, expanded_panel_direction) -> Size:
        """ Calculate the size of a minimised ribbon panel.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetPageBackgroundRedrawArea(self, dc, wnd, page_old_size, page_new_size) -> Rect:
        """ Calculate the portion of a page background which needs to be redrawn when a page is resized.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetPanelClientSize(self, dc, wnd, size, client_offset) -> Size:
        """ Calculate the client size of a panel for a given overall size.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetPanelExtButtonArea(self, dc, wnd, rect) -> Rect:
        """ Calculate the position and size of the panel extension button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetPanelSize(self, dc, wnd, client_size, client_offset) -> Size:
        """ Calculate the size of a panel for a given client size.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetRibbonHelpButtonArea(self, rect: 'Rect') -> Rect:
        """ Calculate the position and size of the ribbonâs help button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetScrollButtonMinimumSize(self, dc, wnd, style) -> Size:
        """ Calculate the minimum size (in pixels) of a scroll button.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetTabCtrlHeight(self, dc, wnd, pages) -> int:
        """ Calculate the height (in pixels) of the tab region of a ribbon bar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def GetToolSize(self, dc, wnd, bitmap_size, kind, is_first, is_last, dropdown_region) -> Size:
        """ Calculate the size of a tool within a   wx.ribbon.RibbonToolBar.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def SetColour(self, id, colour) -> None:
        """ Set the value of a certain colour setting to the value colour.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def SetColourScheme(self, primary, secondary, tertiary) -> None:
        """ Set all applicable colour settings from a few base colours.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def SetFlags(self, flags: int) -> None:
        """ Set the style flags.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def SetFont(self, id, font) -> None:
        """ Set the value of a certain font setting to the value font.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    def SetMetric(self, id, new_val) -> None:
        """ Set the value of a certain integer setting to the value new_val.

            Source: https://docs.wxpython.org/wx.ribbon.RibbonMSWArtProvider.html
        """

    Flags: int  # See GetFlags and SetFlags



RIBBON_SCROLL_BTN_LEFT: int

RIBBON_SCROLL_BTN_RIGHT: int

RIBBON_SCROLL_BTN_UP: int

RIBBON_SCROLL_BTN_DOWN: int

RIBBON_SCROLL_BTN_DIRECTION_MASK: int

RIBBON_SCROLL_BTN_NORMAL: int

RIBBON_SCROLL_BTN_HOVERED: int

RIBBON_SCROLL_BTN_ACTIVE: int

RIBBON_SCROLL_BTN_STATE_MASK: int

RIBBON_SCROLL_BTN_FOR_OTHER: int

RIBBON_SCROLL_BTN_FOR_TABS: int

RIBBON_SCROLL_BTN_FOR_PAGE: int

RIBBON_SCROLL_BTN_FOR_MASK: int

class RibbonPageTabInfo:
    """ A public C++ attribute of type bool.

        Source: https://docs.wxpython.org/wx.ribbon.RibbonPageTabInfo.html
    """
    active: Any  # A public C++ attribute of type bool.
    highlight: Any  # A public C++ attribute of type bool.
    hovered: Any  # A public C++ attribute of type bool.
    ideal_width: Any  # A public C++ attribute of type int.
    minimum_width: Any  # A public C++ attribute of type int.
    page: Any  # A public C++ attribute of type RibbonPage     .
    rect: Any  # A public C++ attribute of type Rect     .
    shown: Any  # A public C++ attribute of type bool.
    small_begin_need_separator_width: Any  # A public C++ attribute of type int.
    small_must_have_separator_width: Any  # A public C++ attribute of type int.



RIBBON_ART_TAB_SEPARATION_SIZE: int

RIBBON_ART_PAGE_BORDER_LEFT_SIZE: int

RIBBON_ART_PAGE_BORDER_TOP_SIZE: int

RIBBON_ART_PAGE_BORDER_RIGHT_SIZE: int

RIBBON_ART_PAGE_BORDER_BOTTOM_SIZE: int

RIBBON_ART_PANEL_X_SEPARATION_SIZE: int

RIBBON_ART_PANEL_Y_SEPARATION_SIZE: int

RIBBON_ART_TOOL_GROUP_SEPARATION_SIZE: int

RIBBON_ART_GALLERY_BITMAP_PADDING_LEFT_SIZE: int

RIBBON_ART_PANEL_LABEL_FONT: int

RIBBON_ART_BUTTON_BAR_LABEL_FONT: int

RIBBON_ART_TAB_LABEL_FONT: int

RIBBON_ART_BUTTON_BAR_LABEL_COLOUR: int

RIBBON_ART_BUTTON_BAR_LABEL_DISABLED_COLOUR: int

RIBBON_ART_BUTTON_BAR_HOVER_BORDER_COLOUR: int

RIBBON_ART_BUTTON_BAR_HOVER_BACKGROUND_TOP_COLOUR: int

RIBBON_ART_BUTTON_BAR_HOVER_BACKGROUND_TOP_GRADIENT_COLOUR: int

RIBBON_ART_BUTTON_BAR_HOVER_BACKGROUND_COLOUR: int

RIBBON_ART_BUTTON_BAR_HOVER_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_BUTTON_BAR_ACTIVE_BORDER_COLOUR: int

RIBBON_ART_BUTTON_BAR_ACTIVE_BACKGROUND_TOP_COLOUR: int

RIBBON_ART_BUTTON_BAR_ACTIVE_BACKGROUND_TOP_GRADIENT_COLOUR: int

RIBBON_ART_BUTTON_BAR_ACTIVE_BACKGROUND_COLOUR: int

RIBBON_ART_BUTTON_BAR_ACTIVE_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_GALLERY_BORDER_COLOUR: int

RIBBON_ART_GALLERY_HOVER_BACKGROUND_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_BACKGROUND_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_BACKGROUND_TOP_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_FACE_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_HOVER_BACKGROUND_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_HOVER_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_HOVER_BACKGROUND_TOP_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_HOVER_FACE_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_ACTIVE_BACKGROUND_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_ACTIVE_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_ACTIVE_BACKGROUND_TOP_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_ACTIVE_FACE_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_DISABLED_BACKGROUND_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_DISABLED_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_DISABLED_BACKGROUND_TOP_COLOUR: int

RIBBON_ART_GALLERY_BUTTON_DISABLED_FACE_COLOUR: int

RIBBON_ART_GALLERY_ITEM_BORDER_COLOUR: int

RIBBON_ART_TAB_LABEL_COLOUR: int

RIBBON_ART_TAB_ACTIVE_LABEL_COLOUR: int

RIBBON_ART_TAB_HOVER_LABEL_COLOUR: int

RIBBON_ART_TAB_SEPARATOR_COLOUR: int

RIBBON_ART_TAB_SEPARATOR_GRADIENT_COLOUR: int

RIBBON_ART_TAB_CTRL_BACKGROUND_COLOUR: int

RIBBON_ART_TAB_CTRL_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_TAB_HOVER_BACKGROUND_TOP_COLOUR: int

RIBBON_ART_TAB_HOVER_BACKGROUND_TOP_GRADIENT_COLOUR: int

RIBBON_ART_TAB_HOVER_BACKGROUND_COLOUR: int

RIBBON_ART_TAB_HOVER_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_TAB_ACTIVE_BACKGROUND_TOP_COLOUR: int

RIBBON_ART_TAB_ACTIVE_BACKGROUND_TOP_GRADIENT_COLOUR: int

RIBBON_ART_TAB_ACTIVE_BACKGROUND_COLOUR: int

RIBBON_ART_TAB_ACTIVE_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_TAB_BORDER_COLOUR: int

RIBBON_ART_PANEL_BORDER_COLOUR: int

RIBBON_ART_PANEL_BORDER_GRADIENT_COLOUR: int

RIBBON_ART_PANEL_HOVER_BORDER_COLOUR: int

RIBBON_ART_PANEL_HOVER_BORDER_GRADIENT_COLOUR: int

RIBBON_ART_PANEL_MINIMISED_BORDER_COLOUR: int

RIBBON_ART_PANEL_MINIMISED_BORDER_GRADIENT_COLOUR: int

RIBBON_ART_PANEL_LABEL_BACKGROUND_COLOUR: int

RIBBON_ART_PANEL_LABEL_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_PANEL_LABEL_COLOUR: int

RIBBON_ART_PANEL_HOVER_LABEL_BACKGROUND_COLOUR: int

RIBBON_ART_PANEL_HOVER_LABEL_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_PANEL_HOVER_LABEL_COLOUR: int

RIBBON_ART_PANEL_MINIMISED_LABEL_COLOUR: int

RIBBON_ART_PANEL_ACTIVE_BACKGROUND_TOP_COLOUR: int

RIBBON_ART_PANEL_ACTIVE_BACKGROUND_TOP_GRADIENT_COLOUR: int

RIBBON_ART_PANEL_ACTIVE_BACKGROUND_COLOUR: int

RIBBON_ART_PANEL_ACTIVE_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_PAGE_BORDER_COLOUR: int

RIBBON_ART_PAGE_BACKGROUND_TOP_COLOUR: int

RIBBON_ART_PAGE_BACKGROUND_TOP_GRADIENT_COLOUR: int

RIBBON_ART_PAGE_BACKGROUND_COLOUR: int

RIBBON_ART_PAGE_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_PAGE_HOVER_BACKGROUND_TOP_COLOUR: int

RIBBON_ART_PAGE_HOVER_BACKGROUND_TOP_GRADIENT_COLOUR: int

RIBBON_ART_PAGE_HOVER_BACKGROUND_COLOUR: int

RIBBON_ART_PAGE_HOVER_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_TOOLBAR_BORDER_COLOUR: int

RIBBON_ART_TOOLBAR_HOVER_BORDER_COLOUR: int

RIBBON_ART_TOOLBAR_FACE_COLOUR: int

RIBBON_ART_TOOL_BACKGROUND_TOP_COLOUR: int

RIBBON_ART_TOOL_BACKGROUND_TOP_GRADIENT_COLOUR: int

RIBBON_ART_TOOL_BACKGROUND_COLOUR: int

RIBBON_ART_TOOL_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_TOOL_HOVER_BACKGROUND_TOP_COLOUR: int

RIBBON_ART_TOOL_HOVER_BACKGROUND_TOP_GRADIENT_COLOUR: int

RIBBON_ART_TOOL_HOVER_BACKGROUND_COLOUR: int

RIBBON_ART_TOOL_HOVER_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_TOOL_ACTIVE_BACKGROUND_TOP_COLOUR: int

RIBBON_ART_TOOL_ACTIVE_BACKGROUND_TOP_GRADIENT_COLOUR: int

RIBBON_ART_TOOL_ACTIVE_BACKGROUND_COLOUR: int

RIBBON_ART_TOOL_ACTIVE_BACKGROUND_GRADIENT_COLOUR: int

RIBBON_ART_BUTTON_BAR_LABEL_HIGHLIGHT_COLOUR: int

RIBBON_ART_BUTTON_BAR_LABEL_HIGHLIGHT_GRADIENT_COLOUR: int

RIBBON_ART_BUTTON_BAR_LABEL_HIGHLIGHT_TOP_COLOUR: int

RIBBON_ART_BUTTON_BAR_LABEL_HIGHLIGHT_GRADIENT_TOP_COLOUR: int




# -*- coding: utf-8 -*-
from typing import Any, ContextManager, Optional, Union

class CalDraw:
    """ A class to draw a calendar.

        Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
    """
    def __init__(self, parent: 'Window') -> None:
        """ Default class constructor

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def AddSelect(self, list, cfont=None, cbackgrd=None) -> None:
        """ Add a selection of days.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def Center(self) -> None:
        """ Calculate the dimensions in the center of the drawing area.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def DefParms(self) -> None:
        """ Setup the default parameters.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def DrawBorder(self, DC, transparent=False) -> None:
        """ Draw a border around the outside of the main display rectangle.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def DrawCal(self, DC, sel_lst=[]) -> None:
        """ Draw the calendar.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def DrawDayText(self, DC, key) -> None:
        """ Draw the day text.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def DrawFocusIndicator(self, DC: 'DC') -> None:
        """ Draw the focus indicator

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def DrawGrid(self, DC: 'DC') -> None:
        """ Calculate and draw the grid lines.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def DrawMonth(self, DC: 'DC') -> None:
        """ Draw the month and year titles.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def DrawNum(self, DC: 'DC') -> None:
        """ Draw the day numbers

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def DrawNumVal(self) -> None:
        """ Draw the numeric values.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def DrawSel(self, DC: 'DC') -> None:
        """ Highlight selected days.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def DrawWeek(self, DC: 'DC') -> None:
        """ Draw the week days.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def GetCal(self) -> None:
        """ Get the calendar days.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def GetColor(self, name: Any) -> None:
        """ Get a color.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def GetOffset(self) -> None:
        """ Get the offset position.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def GetRect(self) -> None:
        """ Get the display rectangle list of the day grid.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def InitScale(self) -> None:
        """ Set the default scale values.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def InitValues(self) -> None:
        """ Default dimensions of various elements of the calendar.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def SetCal(self, year, month) -> None:
        """ Calculate the calendar days and offset position.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def SetColor(self, name, value) -> None:
        """ Set a color.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def SetMarg(self, xmarg, ymarg) -> None:
        """ Set the margins.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def SetPos(self, xpos, ypos) -> None:
        """ Set the position.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def SetSize(self, size: Any) -> None:
        """ Set the size.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def SetWeekColor(self, font_color, week_color) -> None:
        """ Set the font and background color of the week title.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """

    def SetWeekEnd(self, font_color=None, backgrd=None) -> None:
        """ Set the weekend backgrounds.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalDraw.html
        """



class Calendar(Control):
    """ A calendar control class.

        Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
    """
    def __init__(*args, **kwargs) -> None:
        """ Default class constructor.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def AcceptsFocus(self) -> None:
        """ Can it accept focus?

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def AddSelect(self, list, font_color, back_color) -> None:
        """ Add a selection.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def DecMonth(self) -> None:
        """ Decrement the month by 1.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def DecYear(self) -> None:
        """ Decrement the year by 1.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def DoDrawing(self, DC: 'DC') -> None:
        """ Do the drawing.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def DrawFocusIndicator(self, draw: bool) -> None:
        """ Draw the focus indicator or a border.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def DrawRect(self, key, bgcolor='WHITE', fgcolor='PINK', width=0) -> None:
        """ Draw a rectangle.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def DrawRectOrg(self, key, fgcolor='BLACK', width=0) -> None:
        """ Draw a rectangle.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def GetColor(self, name: SetColor) -> None:
        """ Get a color.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def GetDate(self) -> None:
        """ Get the set calendar date.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def GetDay(self) -> None:
        """ Get the set calendar day.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def GetDayHit(self, mx, my) -> None:
        """ Find the clicked area rectangle.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def GetMonth(self) -> None:
        """ Get the set calendar month.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def GetYear(self) -> None:
        """ Get the set calendar year.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def HideGrid(self) -> None:
        """ Hide the calendar grid.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def HideTitle(self) -> None:
        """ Hide the calendar title.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def IncMonth(self) -> None:
        """ Increment the month by 1.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def IncYear(self) -> None:
        """ Increment the year by 1.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def IsDayInWeekend(self, key: Any) -> None:
        """ Is the day in the weekend

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def MoveDate(self, months=0, years=0) -> None:
        """ Move the current date by a given interval of months/years.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def OnKeyDown(self, event) -> None:
        """ Key down event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def OnKillFocus(self, event) -> None:
        """ Kill focus event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def OnLeftDEvent(self, event) -> None:
        """ Left double mouse click event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def OnLeftEvent(self, event) -> None:
        """ Left mouse click event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def OnMiddleDEvent(self, event) -> None:
        """ Middle double mouse click event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def OnMiddleEvent(self, event) -> None:
        """ Middle mouse click event  handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def OnPaint(self, event) -> None:
        """ The on paint event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def OnRightDEvent(self, event) -> None:
        """ Right double mouse click event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def OnRightEvent(self, event) -> None:
        """ Right mouse click event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def OnSetFocus(self, event) -> None:
        """ Set focus event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def OnSize(self, evt) -> None:
        """ The on size event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def ProcessClick(self, event) -> None:
        """ Determine the calendar rectangle click area and draw a selection.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def SelectDay(self, key: Any) -> None:
        """ Select the day.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def SetBusType(self) -> None:
        """ Set the calendar type to âBUSâ.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def SetColor(self, name, value) -> None:
        """ Set a color.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def SetCurrentDay(self) -> None:
        """ Set the current day to today.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def SetDate(self, day, month, year) -> None:
        """ Set a calendar date.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def SetDay(self, day: Any) -> None:
        """ Set the day.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def SetDayValue(self, day: int) -> None:
        """ Set the day.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def SetMargin(self, xmarg, ymarg) -> None:
        """ Set the margins

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def SetMonth(self, month: int) -> None:
        """ Set the Month.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def SetNow(self) -> None:
        """ Set the current day.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def SetSelDay(self, sel: list) -> None:
        """ Set the days to highlight.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def SetSize(self, set_size: Union[tuple[int, int], 'Size']) -> None:
        """ Set the size.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def SetTextAlign(self, vert, horz) -> None:
        """ Set the text alignment.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def SetWeekColor(self, font_color, week_color) -> None:
        """ Set the week title color.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def SetYear(self, year: int) -> None:
        """ Set the year.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def ShowWeekEnd(self) -> None:
        """ Highlight the weekend.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """

    def TestDay(self, key: Any) -> None:
        """ Test to see if the selection has a date and create event.

            Source: https://docs.wxpython.org/wx.lib.calendar.Calendar.html
        """



class CalenDlg(Dialog):
    """ A dialog with a calendar control.

        Source: https://docs.wxpython.org/wx.lib.calendar.CalenDlg.html
    """
    def __init__(self, parent, month=None, day=None, year=None) -> None:
        """ Default class constructor.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalenDlg.html
        """

    def EvtComboBox(self, event) -> None:
        """ The month combobox event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalenDlg.html
        """

    def MouseClick(self, evt) -> None:
        """ The mouse click event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalenDlg.html
        """

    def OnCancel(self, event) -> None:
        """ The Cancel event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalenDlg.html
        """

    def OnMonthSpin(self, event) -> None:
        """ The month spin control event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalenDlg.html
        """

    def OnOk(self, evt) -> None:
        """ The OK event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalenDlg.html
        """

    def OnYrSpin(self, event) -> None:
        """ The year spin control event handler.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalenDlg.html
        """

    def ResetDisplay(self) -> None:
        """ Reset the display.

            Source: https://docs.wxpython.org/wx.lib.calendar.CalenDlg.html
        """



class PrtCalDraw(CalDraw):
    """ A class to optimize CalDraw for printing.

        Source: https://docs.wxpython.org/wx.lib.calendar.PrtCalDraw.html
    """
    def InitValues(self) -> None:
        """ Set initial values.

            Source: https://docs.wxpython.org/wx.lib.calendar.PrtCalDraw.html
        """

    def SetPreview(self, preview: Any) -> None:
        """ Set the preview.

            Source: https://docs.wxpython.org/wx.lib.calendar.PrtCalDraw.html
        """

    def SetPSize(self, pwidth, pheight) -> None:
        """ Calculate the dimensions in the center of the drawing area.

            Source: https://docs.wxpython.org/wx.lib.calendar.PrtCalDraw.html
        """






# -*- coding: utf-8 -*-
from typing import Any, ContextManager, Optional, Union

class iterator:
    """ Read-only forward iterator type.

        Source: https://docs.wxpython.org/wx.grid.GridBlocks.iterator.html
    """





# -*- coding: utf-8 -*-
from typing import Any, ContextManager, Optional, Union

class ChildrenRepositioningGuard:
    """ Helper for ensuring EndRepositioningChildren() is called correctly.

        Source: https://docs.wxpython.org/wx.Window.ChildrenRepositioningGuard.html
    """
    def __init__(self, win: 'Window') -> None:
        """ Constructor calls wx.Window.BeginRepositioningChildren .

            Source: https://docs.wxpython.org/wx.Window.ChildrenRepositioningGuard.html
        """



